from cassandra.concurrent import execute_concurrent_with_args

def save_dataframe_to_cassandra(session, dataframe, table):
    """

    :param session:
    :type session: cassandra.cluster.Session
    :param dataframe:
    :type dataframe: pandas.DataFrame
    :param table:
    :return:
    """
    statement = get_prepared_statement(dataframe, table)

    prepared = session.prepare(statement)

    def dgenerator():
        for x in dataframe.itertuples(index=False):
            yield x

    execute_concurrent_with_args(session, prepared, dgenerator())

def get_prepared_statement(dataframe, table):
    """

    :param session:
    :param dataframe:
    :type dataframe pandas.DataFrame
    :param table:
    :return:
    """
    keys = dataframe.keys()

    str_keys = ", ".join(keys)

    placeholders = ",".join(["?"] * len(keys))

    stmt = "INSERT INTO %s (%s) VALUES (%s)" % (table, str_keys, placeholders)

    return stmt





from setuptools import setup, find_packages

#next time:
#python setup.py register
#python setup.py sdist upload

version = open('ironeagle/VERSION', 'r').readline().strip()

long_desc = """

"""

setup(
    name='ironeagle',
    version=version,
    description='Helper library for working with Pandas and the Cassandra Native Driver',
    long_description=long_desc,
    classifiers = [
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 2.7",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Database",
        
    ],
    keywords='cassandra,cql,pandas',
    install_requires = ['cassandra-driver >= 2.1.0', 'pandas >= 0.15.0'],
    author='Jon Haddad',
    author_email='jon@jonhaddad.com',
    url='https://github.com/rustyrazorblade/ironeagle',
    license='BSD',
    packages=find_packages(),
    include_package_data=True,
)



from cassandra.cluster import Cluster
from pandas import DataFrame
import pytest
from ironeagle import get_prepared_statement, save_dataframe_to_cassandra


@pytest.fixture
def session():
    cluster = Cluster()
    session = cluster.connect("ironeagle")

    create = """
              CREATE TABLE IF NOT EXISTS simple (
              id int primary key,
              name text
              )
              """

    truncate = "truncate simple"

    queries = [create, truncate]

    for q in queries:
        session.execute(q)
    return session


@pytest.fixture
def df():
    df = DataFrame.from_records([(1, "jon"), (2, "pete")],
                                columns=['id', 'name'])
    return df



def test_get_prepared_statement(df):
    prepared = get_prepared_statement(df, "simple")
    assert "id, name" in prepared
    assert "(?,?)" in prepared

def test_insert_data(df, session):
    save_dataframe_to_cassandra(session, df, "simple")
